==> webkitgtk_2.1.90.1.orig.tar.xz: webkitgtk-2.1.90.1/Source/WebCore/bindings/js/WebCoreTypedArrayController.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef WebCoreTypedArrayController_h
#define WebCoreTypedArrayController_h

#include <heap/Weak.h>
#include <runtime/JSGlobalObject.h>
#include <runtime/TypedArrayController.h>

namespace WebCore {

class WebCoreTypedArrayController : public JSC::TypedArrayController {
public:
    WebCoreTypedArrayController();
    virtual ~WebCoreTypedArrayController();
    
    virtual JSC::JSArrayBuffer* toJS(JSC::ExecState*, JSC::JSGlobalObject*, JSC::ArrayBuffer*);
    
    JSC::WeakHandleOwner* wrapperOwner() { return &m_owner; }

private:
    class JSArrayBufferOwner : public JSC::WeakHandleOwner {
    public:
        virtual bool isReachableFromOpaqueRoots(JSC::Handle<JSC::Unknown>, void* context, JSC::SlotVisitor&);
        virtual void finalize(JSC::Handle<JSC::Unknown>, void* context);
    };

    JSArrayBufferOwner m_owner;
};

} // namespace WebCore

#endif // WebCoreTypedArrayController_h

==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebCore/bindings/js/WebCoreTypedArrayController.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef WebCoreTypedArrayController_h
#define WebCoreTypedArrayController_h

#include <heap/Weak.h>
#include <runtime/JSGlobalObject.h>
#include <runtime/TypedArrayController.h>

namespace WebCore {

class WebCoreTypedArrayController : public JSC::TypedArrayController {
public:
    WebCoreTypedArrayController();
    virtual ~WebCoreTypedArrayController();
    
    virtual JSC::JSArrayBuffer* toJS(JSC::ExecState*, JSC::JSGlobalObject*, JSC::ArrayBuffer*) OVERRIDE;
    
    JSC::WeakHandleOwner* wrapperOwner() { return &m_owner; }

private:
    class JSArrayBufferOwner : public JSC::WeakHandleOwner {
    public:
        virtual bool isReachableFromOpaqueRoots(JSC::Handle<JSC::Unknown>, void* context, JSC::SlotVisitor&) OVERRIDE;
        virtual void finalize(JSC::Handle<JSC::Unknown>, void* context) OVERRIDE;
    };

    JSArrayBufferOwner m_owner;
};

} // namespace WebCore

#endif // WebCoreTypedArrayController_h
